Learn R Programming

enviGCMS (version 0.5.0)

getdoe: Filter the data based on DoE, rsd, intensity

Description

Filter the data based on DoE, rsd, intensity

Usage

getdoe(list, inscf = 5, rsdcf = 100, rsdcft = 30, imputation = "l",
  tr = F, index = NULL)

Arguments

list

list with data as peaks list, mz, rt and group information

inscf

Log intensity cutoff for peaks across samples. If any peaks show a intensity higher than the cutoff in any samples, this peaks would not be filtered. default 5

rsdcf

the rsd cutoff of all peaks in all group

rsdcft

the rsd cutoff of all peaks in technical replicates

imputation

parameters for `getimputation` function method

tr

logical. TRUE means dataset with technical replicates at the base level folder

index

the index of peaks considered, default NULL

Value

list with group infomation, filtered peaks and index

See Also

getdata2,getdata, getmzrt,getmzrt2, getimputation, getmr

Examples

Run this code
# NOT RUN {
library(faahKO)
cdfpath <- system.file('cdf', package = 'faahKO')
list <- getmr(cdfpath, pmethod = ' ')
getdoe(list)
# }

Run the code above in your browser using DataLab