Learn R Programming

enviGCMS (version 0.5.0)

getfeaturest: Get the features from t test, with p value, q value, rsd and power restriction

Description

Get the features from t test, with p value, q value, rsd and power restriction

Usage

getfeaturest(list, power = 0.8, pt = 0.05, qt = 0.05, n = 3,
  inscf = 5, rsdcf = 30, imputation = "l", index = NULL)

Arguments

list

list with data as peaks list, mz, rt and group information (two groups)

power

defined power

pt

p value threshold

qt

q value threshold, BH adjust

n

sample numbers in one group

inscf

Log intensity cutoff for peaks across samples. If any peaks show a intensity higher than the cutoff in any samples, this peaks would not be filtered. default 5

rsdcf

the rsd cutoff of all peaks in all group

imputation

parameters for `getimputation` function method

index

the index of peaks considered, default NULL

Value

dataframe with peaks fit the setting above

Examples

Run this code
# NOT RUN {
library(faahKO)
cdfpath <- system.file('cdf', package = 'faahKO')
list <- getmr(cdfpath, pmethod = ' ')
getfeaturest(list)
# }

Run the code above in your browser using DataLab