Learn R Programming

enviGCMS (version 0.5.0)

getupload: Get the csv files to be submitted to Metaboanalyst

Description

Get the csv files to be submitted to Metaboanalyst

Usage

getupload(xset, method = "medret", value = "into", name = "Peaklist")

Arguments

xset

the xcmsset object which you want to submitted to Metaboanalyst

method

parameter for groupval function

value

parameter for groupval function

name

file name

Value

dataframe with data needed for Metaboanalyst if your want to perform local analysis.

See Also

getdata,getupload2, getmzrt

Examples

Run this code
# NOT RUN {
library(faahKO)
cdfpath <- system.file('cdf', package = 'faahKO')
xset <- getdata(cdfpath, pmethod = ' ')
getupload(xset)
# }

Run the code above in your browser using DataLab