plotcc: Plot the calibration curve with error bar, r squared and...

plotccR Documentation

Plot the calibration curve with error bar, r squared and equation

Description

Plot the calibration curve with error bar, r squared and equation

Usage

plotcc(x, y, upper, lower = upper, ...)

Arguments

x

concentration

y

response

upper

upper error bar

lower

lower error bar

...

parameters for 'plot' function

Examples

## Not run: 
plotcc(x,y,upper)

## End(Not run)

enviGCMS documentation built on Oct. 10, 2026, 5:06 p.m.