Learn R Programming

enviGCMS (version 0.5.0)

plotmr: plot the scatter plot for peaks list with threshold

Description

plot the scatter plot for peaks list with threshold

Usage

plotmr(list, rt = NULL, ms = NULL, inscf = 5, rsdcf = 30,
  imputation = "l", index = NULL, ...)

Arguments

list

list with data as peaks list, mz, rt and group information

rt

vector range of the retention time

ms

vector vector range of the m/z

inscf

Log intensity cutoff for peaks across samples. If any peaks show a intensity higher than the cutoff in any samples, this peaks would not be filtered. default 5

rsdcf

the rsd cutoff of all peaks in all group

imputation

parameters for `getimputation` function method

index

the index of peaks considered, default NULL

...

parameters for `plot` function

Value

data fit the cutoff

Examples

Run this code
# NOT RUN {
library(faahKO)
cdfpath <- system.file('cdf', package = 'faahKO')
list <- getmr(cdfpath, pmethod = ' ')
plotmr(list)
# }

Run the code above in your browser using DataLab