| getHRMF | R Documentation |
Applies HRMF to every compound in an MSP file that has a
chemical formula annotation.
getHRMF(
file,
charge = 1,
adduct = NULL,
mass_accuracy = 5,
intensity_cutoff = 1,
IR_RelAb_cutoff = 1
)
file |
character. Path to an MSP file. |
charge |
integer. Charge state (see |
adduct |
character vector of adduct names or named numeric vector of
custom mass deltas (see |
mass_accuracy |
numeric. Mass accuracy in ppm. Default 5. |
intensity_cutoff |
numeric. Minimum absolute intensity. Default 1. |
IR_RelAb_cutoff |
numeric. Relative abundance cutoff (%) for theoretical isotopologues. Default 1. |
A named list where each element contains the HRMF results for one compound (with a valid formula) from the MSP file.
HRMF, getMSP
## Not run:
results <- getHRMF("library.msp")
# LC-MS/MS library with protonated ions
results <- getHRMF("library.msp", adduct = "[M+H]+")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.