Learn R Programming

enviGCMS (version 0.5.0)

getmzrt: Get the mzrt profile and group information for batch correction and plot as a list

Description

Get the mzrt profile and group information for batch correction and plot as a list

Usage

getmzrt(xset, name = NULL)

Arguments

xset

xcmsSet objects

name

file name for csv file, default NULL

Value

list with rtmz profile and group infomation

See Also

getdata,getupload, getmzrt2, getdoe,getmzrt

Examples

Run this code
# NOT RUN {
library(faahKO)
cdfpath <- system.file('cdf', package = 'faahKO')
xset <- getdata(cdfpath, pmethod = ' ')
getmzrt(xset)
# }

Run the code above in your browser using DataLab